@@ -4,17 +4,15 @@ from collections import defaultdict
 
 from rest_framework import serializers
 
-from network.base.db_api import DBConnectionError, \
-    get_tle_sets_by_norad_id_set, get_transmitters_by_uuid_set
-from network.base.models import Antenna, DemodData, FrequencyRange, \
-    Observation, Station, Transmitter
-from network.base.perms import UserNoPermissionError, \
-    check_schedule_perms_per_station
+from network.base.db_api import DBConnectionError, get_tle_sets_by_norad_id_set, \
+    get_transmitters_by_uuid_set
+from network.base.models import Antenna, DemodData, FrequencyRange, Observation, Station
+from network.base.perms import UserNoPermissionError, check_schedule_perms_per_station
 from network.base.scheduling import create_new_observation
 from network.base.stats import transmitter_stats_by_uuid
-from network.base.validators import ObservationOverlapError, OutOfRangeError, \
-    check_end_datetime, check_overlaps, check_start_datetime, \
-    check_start_end_datetimes, check_transmitter_station_pairs
+from network.base.validators import ObservationOverlapError, OutOfRangeError, check_end_datetime, \
+    check_overlaps, check_start_datetime, check_start_end_datetimes, \
+    check_transmitter_station_pairs
 
 
 class DemodDataSerializer(serializers.ModelSerializer):
@@ -39,6 +37,9 @@ class ObservationSerializer(serializers.ModelSerializer):
     vetted_user = serializers.SerializerMethodField()  # Deprecated
     vetted_datetime = serializers.SerializerMethodField()  # Deprecated
     demoddata = DemodDataSerializer(required=False, many=True)
+    tle0 = serializers.SerializerMethodField()
+    tle1 = serializers.SerializerMethodField()
+    tle2 = serializers.SerializerMethodField()
 
     class Meta:
         model = Observation
@@ -52,7 +53,7 @@ class ObservationSerializer(serializers.ModelSerializer):
             'transmitter_uplink_low', 'transmitter_uplink_high', 'transmitter_uplink_drift',
             'transmitter_downlink_low', 'transmitter_downlink_high', 'transmitter_downlink_drift',
             'transmitter_mode', 'transmitter_invert', 'transmitter_baud', 'transmitter_updated',
-            'tle'
+            'tle0', 'tle1', 'tle2'
         )
         read_only_fields = [
             'id', 'start', 'end', 'observation', 'ground_station', 'transmitter', 'norad_cat_id',
@@ -63,7 +64,8 @@ class ObservationSerializer(serializers.ModelSerializer):
             'transmitter_type', 'transmitter_uplink_low', 'transmitter_uplink_high',
             'transmitter_uplink_drift', 'transmitter_downlink_low', 'transmitter_downlink_high',
             'transmitter_downlink_drift', 'transmitter_mode', 'transmitter_invert',
-            'transmitter_baud', 'transmitter_created', 'transmitter_updated', 'tle'
+            'transmitter_baud', 'transmitter_created', 'transmitter_updated', 'tle0', 'tle1',
+            'tle2'
         ]
 
     def update(self, instance, validated_data):
@@ -141,6 +143,18 @@ class ObservationSerializer(serializers.ModelSerializer):
         """DEPRECATED: Returns vetted datetime"""
         return obj.waterfall_status_datetime
 
+    def get_tle0(self, obj):
+        """Returns tle0"""
+        return obj.tle_line_0
+
+    def get_tle1(self, obj):
+        """Returns tle1"""
+        return obj.tle_line_1
+
+    def get_tle2(self, obj):
+        """Returns tle2"""
+        return obj.tle_line_2
+
 
 class NewObservationListSerializer(serializers.ListSerializer):
     """SatNOGS Network New Observation API List Serializer"""
@@ -305,10 +319,7 @@ class NewObservationSerializer(serializers.Serializer):
         )
 
     def update(self, instance, validated_data):
-        """Updates an observation from validated data
-
-        currently disabled and returns None
-        """
+        """Updates an observation from validated data, currently disabled and returns None"""
         return None
 
     class Meta:
@@ -460,17 +471,26 @@ class JobSerializer(serializers.ModelSerializer):
         return obj.transmitter_baud
 
 
-class TransmitterSerializer(serializers.ModelSerializer):
+class TransmitterSerializer(serializers.Serializer):
     """SatNOGS Network Transmitter API Serializer"""
+    uuid = serializers.SerializerMethodField()
     stats = serializers.SerializerMethodField()
 
-    class Meta:
-        model = Transmitter
-        fields = ('uuid', 'sync_to_db', 'stats')
+    def get_uuid(self, obj):
+        """Returns Transmitter UUID"""
+        return obj['transmitter_uuid']
 
     def get_stats(self, obj):
         """Returns Transmitter statistics"""
-        stats = transmitter_stats_by_uuid(obj.uuid)
+        stats = transmitter_stats_by_uuid(obj['transmitter_uuid'])
         for statistic in stats:
             stats[statistic] = int(stats[statistic])
         return stats
+
+    def create(self, validated_data):
+        """Creates an object instance of transmitter, currently disabled and returns None"""
+        return None
+
+    def update(self, instance, validated_data):
+        """Updates an object instance of transmitter, currently disabled and returns None"""
+        return None
