@@ -1,12 +1,8 @@
 """Define functions and settings for the django admin base interface"""
-from django.conf.urls import url
-from django.contrib import admin, messages
-from django.shortcuts import redirect
-from django.urls import reverse
+from django.contrib import admin
 
-from network.base.models import Antenna, AntennaType, DemodData, \
-    FrequencyRange, Observation, Satellite, Station, Tle, Transmitter
-from network.base.tasks import sync_to_db
+from network.base.models import Antenna, AntennaType, DemodData, FrequencyRange, Observation, \
+    Satellite, Station
 from network.base.utils import export_as_csv, export_station_status
 
 
@@ -115,50 +111,6 @@ class SatelliteAdmin(admin.ModelAdmin):
     search_fields = ('name', 'norad_cat_id', 'norad_follow_id')
 
 
-@admin.register(Tle)
-class TleAdmin(admin.ModelAdmin):
-    """Define TLE view in django admin UI"""
-    list_display = ('satellite_name', 'tle0', 'tle1', 'updated', 'tle_source')
-    list_filter = ('tle_source', 'satellite__name')
-
-    def satellite_name(self, obj):  # pylint: disable=no-self-use
-        """Return the satellite name"""
-        return obj.satellite.name
-
-
-@admin.register(Transmitter)
-class TransmitterAdmin(admin.ModelAdmin):
-    """Define Transmitter view in django admin UI"""
-    list_display = ('uuid', 'sync_to_db')
-    search_fields = ('uuid', )
-    list_filter = ('sync_to_db', )
-    readonly_fields = ('uuid', )
-
-    def get_urls(self):
-        """Returns django urls for the Transmitter view
-
-        sync_to_db -- url for the sync_to_db function
-
-        :returns: Django urls for the Transmitter admin view
-        """
-        urls = super(TransmitterAdmin, self).get_urls()
-        my_urls = [
-            url(r'^sync_to_db/$', self.sync_to_db, name='sync_to_db'),
-        ]
-        return my_urls + urls
-
-    def sync_to_db(self, request):  # pylint: disable=R0201
-        """Returns the admin home page, while triggering a Celery sync to DB task
-
-        Forces sync of unsynced demoddata for all transmitters that have set to be synced
-
-        :returns: admin home page redirect with popup message
-        """
-        sync_to_db.delay()
-        messages.success(request, 'Sync to DB task was triggered successfully!')
-        return redirect(reverse('admin:index'))
-
-
 class DemodDataInline(admin.TabularInline):
     """Define DemodData inline template for use in Observation view in django admin UI"""
     model = DemodData
@@ -175,4 +127,3 @@ class ObservationAdmin(admin.ModelAdmin):
     inlines = [
         DemodDataInline,
     ]
-    readonly_fields = ('tle', )
