@@ -365,7 +365,7 @@ class Observation(models.Model):
     0 =< x < 100  -> Unknown (Future if observation not completed)
     100 =< x      -> Good
     """
-    status = models.SmallIntegerField(default=0)
+    status = models.SmallIntegerField(default=0, db_index=True)
     testing = models.BooleanField(default=False)
     rise_azimuth = models.FloatField(blank=True, null=True)
     max_altitude = models.FloatField(blank=True, null=True)
@@ -390,6 +390,14 @@ class Observation(models.Model):
     transmitter_invert = models.BooleanField(default=False)
     transmitter_baud = models.FloatField(validators=[MinValueValidator(0)], blank=True, null=True)
     transmitter_created = models.DateTimeField(default=now)
+    station_alt = models.PositiveIntegerField(null=True)
+    station_lat = models.FloatField(
+        validators=[MaxValueValidator(90), MinValueValidator(-90)], null=True
+    )
+    station_lng = models.FloatField(
+        validators=[MaxValueValidator(180), MinValueValidator(-180)], null=True
+    )
+    station_antennas = models.TextField(null=True)
 
     objects = ObservationManager.as_manager()
 
